@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20250414';
+our $VERSION = '5.20250528';
 our %utilities;
 
 sub utilities {
@@ -2126,6 +2126,27 @@ my %delta = (
         removed => {
         }
     },
+    5.041011 => {
+        delta_from => 5.041010,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.041012 => {
+        delta_from => 5.041011,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.041013 => {
+        delta_from => 5.041012,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
